pub enum PrimitiveKind {
Show 14 variants
Picture {
data_handle: Handle<Picture>,
pic_index: PictureIndex,
},
TextRun {
data_handle: Handle<TextRun>,
},
LineDecoration {
data_handle: Handle<LineDecoration>,
},
NormalBorder {
data_handle: Handle<NormalBorderPrim>,
},
ImageBorder {
data_handle: Handle<ImageBorder>,
},
Rectangle {
data_handle: Handle<RectanglePrim>,
},
YuvImage {
data_handle: Handle<YuvImage>,
},
Image {
data_handle: Handle<Image>,
},
LinearGradient {
data_handle: Handle<LinearGradient>,
},
RadialGradient {
data_handle: Handle<RadialGradient>,
},
ConicGradient {
data_handle: Handle<ConicGradient>,
},
BackdropCapture {
data_handle: Handle<BackdropCapture>,
},
BackdropRender {
data_handle: Handle<BackdropRender>,
pic_index: PictureIndex,
},
BoxShadow {
data_handle: Handle<BoxShadow>,
},
}Variants
Picture
Direct reference to a Picture
Fields

pic_index: PictureIndexTextRun
A run of glyphs, with associated font parameters.
LineDecoration
A line decoration. cache_handle refers to a cached render task handle, if this line decoration is not a simple solid.
Fields

data_handle: Handle<LineDecoration>Handle to the common interned data for this primitive.
NormalBorder
Fields

data_handle: Handle<NormalBorderPrim>Handle to the common interned data for this primitive.
ImageBorder
Fields

data_handle: Handle<ImageBorder>Handle to the common interned data for this primitive.
Rectangle
Fields

data_handle: Handle<RectanglePrim>Handle to the common interned data for this primitive.
YuvImage
Image
LinearGradient
Fields

data_handle: Handle<LinearGradient>Handle to the common interned data for this primitive.
RadialGradient
Fields

data_handle: Handle<RadialGradient>Handle to the common interned data for this primitive.
ConicGradient
Fields

data_handle: Handle<ConicGradient>Handle to the common interned data for this primitive.
BackdropCapture
Render a portion of a specified backdrop.
Fields

data_handle: Handle<BackdropCapture>BackdropRender
BoxShadow
Implementations
Sourceimpl PrimitiveKind
impl PrimitiveKind
pub fn as_pic(&self) -> PictureIndex