pub struct PrimTemplateCommonData {
pub flags: PrimitiveFlags,
pub opacity: PrimitiveOpacity,
pub gpu_buffer_address: GpuBufferAddress,
pub aligned_aa_edges: EdgeMask,
pub transformed_aa_edges: EdgeMask,
}Fields
flags: PrimitiveFlagsopacity: PrimitiveOpacitygpu_buffer_address: GpuBufferAddressAddress of the per-primitive data in the GPU cache.
TODO: This is only valid during the current frame and must be overwritten each frame. We should move this out of the common data to avoid accidental reuse.
aligned_aa_edges: EdgeMasktransformed_aa_edges: EdgeMaskImplementations
Sourceimpl PrimTemplateCommonData
impl PrimTemplateCommonData
pub fn with_key_common(common: PrimKeyCommonData) -> Self